==> haskell-network-uri-2.6.1.0-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network-uri.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-uri
version: 2.6.1.0
id: network-uri-2.6.1.0-70Dn88tZogC6ueZsHNuWT3
key: network-uri-2.6.1.0-70Dn88tZogC6ueZsHNuWT3
license: BSD3
maintainer: ezra@ezrakilty.net
homepage: https://github.com/haskell/network-uri
synopsis: URI manipulation
description:
    This package provides an URI manipulation interface.
    .
    In network-2.6 the @Network.URI@ module was split off from the
    network package into this package. If you'\''re using the @Network.URI@
    module you can automatically get it from the right package by adding
    this to your .cabal file:
    .
    > flag network-uri
    >   description: Get Network.URI from the network-uri package
    >   default: True
    >
    > library
    >   -- ...
    >   if flag(network-uri)
    >     build-depends: network-uri >= 2.6, network >= 2.6
    >   else
    >     build-depends: network-uri < 2.6, network < 2.6
    .
    That is, get the module from either network < 2.6 or from
    network-uri >= 2.6.
category: Network
exposed: True
indefinite: False
exposed-modules:
    Network.URI
abi: afebcc3944e17103658dd7506cfde008
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/network-uri-2.6.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/network-uri-2.6.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/network-uri-2.6.1.0
hs-libraries: HSnetwork-uri-2.6.1.0-70Dn88tZogC6ueZsHNuWT3
depends:
    base-4.10.1.0 deepseq-1.4.3.0 parsec-3.1.13.0-lnA0oAxTgL1KjACiBdQ3F
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
             parsec-3.1.13.0-lnA0oAxTgL1KjACiBdQ3F=688f5e7444a80128e4a1c39bd128d195
haddock-interfaces: /usr/share/doc/haskell-network-uri/html/network-uri.haddock
haddock-html: /usr/share/doc/haskell-network-uri/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-uri-2.6.1.0-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network-uri.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-uri
version: 2.6.1.0
id: network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
key: network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
license: BSD-3-Clause
maintainer: ezra@ezrakilty.net
homepage: https://github.com/haskell/network-uri
synopsis: URI manipulation
description:
    This package provides an URI manipulation interface.
    .
    In network-2.6 the @Network.URI@ module was split off from the
    network package into this package. If you'\''re using the @Network.URI@
    module you can automatically get it from the right package by adding
    this to your .cabal file:
    .
    > flag network-uri
    >   description: Get Network.URI from the network-uri package
    >   default: True
    >
    > library
    >   -- ...
    >   if flag(network-uri)
    >     build-depends: network-uri >= 2.6, network >= 2.6
    >   else
    >     build-depends: network-uri < 2.6, network < 2.6
    .
    That is, get the module from either network < 2.6 or from
    network-uri >= 2.6.
category: Network
abi: d49fd54c7cc8ca7cdc7f65925221d670
exposed: True
exposed-modules:
    Network.URI
import-dirs: /usr/lib/ghc-8.4.2/site-local/network-uri-2.6.1.0
library-dirs: /usr/lib/ghc-8.4.2/site-local/network-uri-2.6.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/network-uri-2.6.1.0
hs-libraries: HSnetwork-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
depends:
    base-4.11.1.0 deepseq-1.4.3.0 parsec-3.1.13.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             deepseq-1.4.3.0=521dff49867cc7581bb7066827d3f18e
             parsec-3.1.13.0=b976f306e11b572c7d5898bcff511199
haddock-interfaces: /usr/share/doc/haskell-network-uri/html/network-uri.haddock
haddock-html: /usr/share/doc/haskell-network-uri/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
